# h4rm3l

[![PyPI - Version](https://img.shields.io/pypi/v/h4rm3l.svg)](https://pypi.org/project/h4rm3l)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/h4rm3l.svg)](https://pypi.org/project/h4rm3l)

-----
## Installation

```console
pip install h4rm3l
```

## Links
- [Home Page](https://mdoumbouya.github.io/h4rm3l/)
- [Report an Issue](https://github.com/mdoumbouya/h4rm3l/issues)
- [Source on GitHub](https://github.com/mdoumbouya/h4rm3l)

## License
`h4rm3l` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Citation
`h4rm3l` can be cited as:
```
@misc{doumbouya2024h4rm3l,
      title={h4rm3l: A Dynamic Benchmark of Composable Jailbreak Attacks for LLM Safety Assessment}, 
      author={Moussa Koulako Bala Doumbouya and Ananjan Nandi and Gabriel Poesia and Davide Ghilardi and Anna Goldie and Federico Bianchi and Dan Jurafsky and Christopher D. Manning},
      year={2024},
      eprint={2408.04811},
      archivePrefix={arXiv},
      primaryClass={cs.CR},
      url={https://arxiv.org/abs/2408.04811}, 
}
```